@@ -6,7 +6,7 @@ use warnings;
 
 use vars qw($VERSION);
 
-$VERSION = '0.1103';
+$VERSION = '0.0.2';
 
 use Exception::Class (
     'App::Sky::Exception',
@@ -30,7 +30,7 @@ App::Sky::Exception - provides various exception classes for App::Sky
 
 =head1 VERSION
 
-version 0.0.1
+version 0.0.2
 
 =head1 SYNOPSIS
 
@@ -187,8 +187,8 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/perl-App-Sky>
+L<https://github.com/shlomif/Sky-uploader>
 
-  hg clone ssh://hg@bitbucket.org/shlomif/perl-App-Sky
+  git clone git://github.com/shlomif/Sky-uploader.git
 
 =cut
