@@ -3,7 +3,7 @@ package App::Sky::Manager;
 use strict;
 use warnings;
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.0.2';
 
 
 use Carp ();
@@ -126,7 +126,7 @@ App::Sky::Manager - manager for the configuration.
 
 =head1 VERSION
 
-version 0.0.1
+version 0.0.2
 
 =encoding utf8
 
@@ -305,8 +305,8 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/perl-App-Sky>
+L<https://github.com/shlomif/Sky-uploader>
 
-  hg clone ssh://hg@bitbucket.org/shlomif/perl-App-Sky
+  git clone git://github.com/shlomif/Sky-uploader.git
 
 =cut
